@@ -1,8 +1,8 @@
-from operations_with_objects.operations_with_objects import OperationsWithObjects
-from operations_with_objects.system_object import SystemObject
-from quick_resto_api import QuickRestoApi
-from quick_resto_objects.modules.warehouse.semi_product import SemiProduct
-from quick_resto_objects.modules.warehouse.store_category import StoreCategory
+from quick_resto_API.operations_with_objects.operations_with_objects import OperationsWithObjects
+from quick_resto_API.operations_with_objects.system_object import SystemObject
+from quick_resto_API.quick_resto_api import QuickRestoApi
+from quick_resto_API.quick_resto_objects.modules.warehouse.semi_product import SemiProduct
+from quick_resto_API.quick_resto_objects.modules.warehouse.store_category import StoreCategory
 
 class SemiProductOperations(SystemObject):
     def __init__(self, api: QuickRestoApi):
