@@ -1,8 +1,8 @@
-from operations_with_objects.operations_with_objects import OperationsWithObjects
-from operations_with_objects.system_object import SystemObject
-from quick_resto_api import QuickRestoApi
-from quick_resto_objects.modules.warehouse.single_category import SingleCategory
-from quick_resto_objects.modules.warehouse.single_product import SingleProduct
+from quick_resto_API.operations_with_objects.operations_with_objects import OperationsWithObjects
+from quick_resto_API.operations_with_objects.system_object import SystemObject
+from quick_resto_API.quick_resto_api import QuickRestoApi
+from quick_resto_API.quick_resto_objects.modules.warehouse.single_category import SingleCategory
+from quick_resto_API.quick_resto_objects.modules.warehouse.single_product import SingleProduct
 
 class SingleProductOperations(SystemObject):
     def __init__(self, api: QuickRestoApi):
