@@ -1,6 +1,6 @@
-from quick_resto_objects.modules.warehouse.cooking_place import CookingPlace
-from quick_resto_objects.modules.warehouse.sale_place import SalePlace
-from quick_resto_objects.quick_resto_object import QuickRestoObject
+from quick_resto_API.quick_resto_objects.modules.warehouse.cooking_place import CookingPlace
+from quick_resto_API.quick_resto_objects.modules.warehouse.sale_place import SalePlace
+from quick_resto_API.quick_resto_objects.quick_resto_object import QuickRestoObject
 
 
 class DishSale(QuickRestoObject):
